@@ -12,7 +12,7 @@ from .logging import createLogger
 from .helpers import jsonAvailable, json, urlFor, jsonify, sendFile, flash, getFlashedMessage
 from .routing import Router, Resource, RESTfulRule, Root, Group
 from .shared import request, session, shared, _requestContextStack, _appContextStack, currentApp
-from .template import renderTemplate, renderTempalteString
+from .template import renderTemplate, renderTemplateString
 from .wrappers import Request, Response
 from .cache import Cache
 
