@@ -30,10 +30,12 @@ from shimehari.session import SessionStore
 from shimehari.shared import _requestContextStack, _SharedRequestClass, request
 from shimehari.template import _defaultTemplateCtxProcessor
 from shimehari.core.exceptions import ShimehariSetupError
-from shimehari.core.signals import appContextTearingDown, requestContextTearingDown
+from shimehari.core.signals import appContextTearingDown, requestContextTearingDown, requestStarted, requestFinished, gotRequestException
 
 
 _loggerLock = Lock()
+defaultHost = '127.0.0.1'
+defaultPort = 5959
 
 
 def setupMethod(f):
@@ -104,7 +106,8 @@ class Shimehari(_Kouzi):
 
     sharedRequestClass = _SharedRequestClass
 
-    allowedMethods = set(['HEAD', 'GET', 'OPTIONS', 'POST', 'PUT', 'TRACE', 'DELETE', 'PATCH'])
+    allowedMethods = set(['GET', 'HEAD', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'PATCH'])
+    bodylessMethods = frozenset(['GET', 'HEAD', 'OPTIONS', 'DELETE'])
 
     def __init__(self, importName,
                  staticURL=None, staticFolder='static',
@@ -150,7 +153,7 @@ class Shimehari(_Kouzi):
 
         self.debug = self.config['DEBUG']
         self.test = self.config['TEST']
-        self.sessionKey = self.config['SECRET_KEY']
+        self.sessionKey = self.config['SESSION_COOKIE_NAME']
         self.useXSendFile = self.config['USE_X_SENDFILE']
 
         self.templateOptions = templateOptions
@@ -243,7 +246,7 @@ class Shimehari(_Kouzi):
         return response
 
     def openSession(self, request):
-        sid = request.cookies.get(self.sessionKey, None)
+        sid = request.cookies.get(self.sessionKey, None) or request.values.get(self.sessionKey, None)
         if sid is None:
             return self.sessionStore.new()
         else:
@@ -431,10 +434,12 @@ class Shimehari(_Kouzi):
         if request is not None:
 
             if request.environ['REQUEST_METHOD'] == 'POST':
-                if '_method' in request.form:
-                    method = request.form['_method'].upper()
-                    if method in self.allowedMethods:
-                        request.environ['REQUEST_METHOD'] = method
+                method = request.form.get('_method', '').upper() or request.environ.get('HTTP_X_HTTP_METHOD_OVERRIDE', '').upper()
+                if method in self.allowedMethods:
+                    method = method.encode('ascii', 'replace')
+                    request.environ['REQUEST_METHOD'] = method
+                if method in self.bodylessMethods:
+                    request.environ['CONTENT_LENGTH'] = 0
 
             return self.router.bind_to_environ(request.environ)
         #なんのこっちゃ
@@ -508,6 +513,7 @@ class Shimehari(_Kouzi):
         """
         self.tryTriggerBeforeFirstRequest()
         try:
+            requestStarted.send(self)
             rv = self.preprocessRequest()
             if rv is None:
                 req = _requestContextStack.top.request
@@ -520,6 +526,7 @@ class Shimehari(_Kouzi):
 
         response = self.makeResponse(rv)
         response = self.processResponse(response)
+        requestFinished.send(self, response=response)
 
         return response
 
@@ -560,6 +567,8 @@ class Shimehari(_Kouzi):
         """
 
         excType, excValue, excTb = sys.exc_info()
+
+        gotRequestException.send(self, exception=e)
         handler = self.errorHandlerSpec[None].get(500)
 
         if self.propagateExceptions:
@@ -635,7 +644,7 @@ class Shimehari(_Kouzi):
                 response = self.makeResponse(self.handleException(e))
             return response(environ, startResponse)
 
-    def drink(self, host, port, debug=None, **options):
+    def drink(self, host=None, port=None, debug=None, **options):
         u"""アプリを実行します。
 
         :param host:    ホスト名
@@ -643,6 +652,10 @@ class Shimehari(_Kouzi):
         :param debug:   デバッグモードとして起動するかどうか
         :param options: kwargs
         """
+
+        host = host or defaultHost
+        port = port or defaultPort
+
         from werkzeug.serving import run_simple
         if debug is not None:
             self.debug = bool(debug)
@@ -660,7 +673,7 @@ class Shimehari(_Kouzi):
             単純に drink メソッドをラップしているだけです。
             WSGI 周りのライブラリや既存のコードで run を自動的に呼ぶ物がおおいので念のため。
         """
-        self.drink(host, port, debug, options)
+        self.drink(host, port, debug, **options)
 
     def testClient(self, useCookies=True):
         cls = self.testClientCls
