@@ -17,7 +17,9 @@ except ImportError:
             self.doc = doc
 
         def _fail(self, *args, **options):
-            raise RuntimeError('ooooo')
+            raise RuntimeError('signalling support is unavailable '
+                               'because the blinker library is '
+                               'not installed.')
 
         send = lambda *a, **kw: None
         connect = disconnect = has_recivers_for = recivers_for = temporaily_connected_to = connected_to = _fail
@@ -26,5 +28,9 @@ except ImportError:
 
 _signals = Namespace()
 
+templateRendered = _signals.signal('template-rendered')
+requestStarted = _signals.signal('request-started')
+requestFinished = _signals.signal('request-finished')
 requestContextTearingDown = _signals.signal('requestcontext-tearing-down')
+gotRequestException = _signals.signal('got-request-exception')
 appContextTearingDown = _signals.signal('appcontext-tearing-down')
